local nebu_img = require "bkg.lib.nebula_image"
nebu_img.init( "messier" )
